import java.awt.*;

/**
 * A valid circle, with a center point and radius.
 */
public class Circle {
    /** The center of circle */
    private Point center;
    /** The radius of circle */
    private int radius;

    // AF(this) = a circle c such that
    // c.center = this.center
    // c.radius = this.radius
    // Rep invariant:
    // center != null && radius > 0

    /**
     * Constructor that creates a circle.
     *
     * @param center center of circle to be created
     * @param radius radius of circle to be created
     * @throws IllegalArgumentException if center == null || radius < 1
     */
    public Circle(Point center, int radius) {
        this.center = center;
        this.radius = radius;
        checkRep();
    }

    /**
     * Returns radius of the circle
     * @return radius of the circle
     */
    public int getRadius() {
        return radius;
    }

    /**
     * Returns center of the circle
     * @return center
     */
    public Point getCenter() {
        return center;
    }

    /**
     * Add a value to radius
     * @param add value added to radius
     * @spec.requires add > -radius
     * @spec.modifies radius
     * @spec.effects change radius to add + radius
     * @return true iff add + radius > 0
     */
    public boolean addRadius(int add) {
        checkRep();
        if (add + radius <= 0) {
            return false;
        }
        this.radius += add;
        checkRep();
        return true;
    }

    /**
     * checks if rep invariants hold
     */
    private void checkRep() {
        assert center != null && radius > 0;
    }

}
